@@ -305,7 +305,7 @@ class CounterWithTimeWindowMixin(object):
     @classmethod
     def current_day_counter(cls):
 
-        return (pytz.utc.localize(datetime.datetime.now()).astimezone(cls.timezone) - cls.count_from.date()).days
+        return (pytz.utc.localize(datetime.datetime.now()).astimezone(cls.timezone).date() - cls.count_from.date()).days
 
     @classmethod
     def _current_value(cls, value):
