@@ -40,4 +40,10 @@ class RedisClientWithRetry(object):
         raise error
 
 def chunker(seq, size):
-    return (seq[pos:pos + size] for pos in range(0, len(seq), size))
\ No newline at end of file
+    return (seq[pos:pos + size] for pos in range(0, len(seq), size))
+
+def search_obj_from_array(array, fieldname, fieldvalue):
+    _obj = [o for o in array if o.get(fieldname, str(fieldvalue) + 'not_it') == fieldvalue]
+    if len(_obj) == 0:
+        return None
+    return _obj[0]
\ No newline at end of file
